/// @addtogroup homology
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file bitcode.h
///
/// @author Pawel Pilarczyk
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2007 by Pawel Pilarczyk.
//
// This file is part of the Homology Library.  This library is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started on November 12, 2001. Last revision: September 2, 2003.


#ifndef _CAPD_BITCODE_H_
#define _CAPD_BITCODE_H_

#include "homology/config.h"
#include "homology/textfile.h"
#include "homology/pointset.h"

#include <iostream>
#include <fstream>
#include <ctime>
#include <cstdlib>

namespace capd {
namespace homology {


// --------------------------------------------------
// --------------------- BITCODE --------------------
// --------------------------------------------------

// Read a set of points encoded in the "bitcode" format used by Bill Kalies.
// The depth of bit codes is saved to '*bitcode_depth' unless NULL.
// Return 0 on success and -1 on error (and display a message).
int readbitpoints (textfile &f, pointset &p, int *bitcode_depth = NULL);

// Write a set of points encoded in the "bitcode" format.
// If 'sorted', bit codes are sorted as the software by Bill Kalies needs.
// Otherwise they are saved in the same order as the points in 'p'.
// The depth of bit fields is determined automatically to the minimal
// necessary value unless 'fixed_depth' is positive.
// As the lower left corner, the minimal coordinates of the points are
// selected unless 'fixed_corner' is NULL.
// Return 0 on success and -1 on error (and display a message).
int writebitpoints (std::ostream &out, pointset &p, bool sorted = true,
	int fixed_depth = 0, coordinate *fixed_corner = NULL);

} // namespace homology
} // namespace capd

#endif

/// @}
