/// @addtogroup homology
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file config.h
///
/// @author Pawel Pilarczyk
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2007 by Pawel Pilarczyk.
//
// This file is part of the Homology Library.  This library is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started in 2002. Last revision: September 21, 2006.


#ifndef _CAPD_OPTIONS_H_
#define _CAPD_OPTIONS_H_


// System-dependent definitions:
// -----------------------------
// ppDOS - if compiled under DOS (important for opening binary files)
// ppUNIX - if compiled with a Unix-style compiler (GNU C++, for example)

// Note: For system-dependent definitions it is recommended that you set
// appropriate "define"s with your compiler directly (e.g. in a make file)
// instead of modifying this file, because the code below attempts
// to determine reasonable settings if none are specified.
// Other options must be adjusted in this header file to make your programs
// recompile with the new settings.

// --------------------------------------------------

// operating system choice: Unix-like or DOS/Windows-like;
// define ppDOS for opening binary files with the "ios::binary" flag;
// define ppUNIX to activate Unix-characteristic behavior of programs
// and to suppress functions inavailable under Unix;
// define both for GNU C++ compilers for DOS/Windows
//
#if (defined (ppUNIX) || defined (ppDOS))
#elif ((defined __GNUC__) && (defined __WIN32__))
	#define ppDOS
	#define ppUNIX
#elif (defined (DJGPP) || defined (DEVCPP) || defined (MINGW))
	#define ppDOS
	#define ppUNIX
#elif (defined (_BORLANDC_) || defined (__BORLANDC__) || defined (_MSC_VER))
	#define ppDOS
#else
	#define ppUNIX
#endif

// a replacement for the "bad_alloc" exception for incompatible compilers
//
//#if (defined (_MSC_VER) || (defined (__GNUC__) && \backslash
//	(((__GNUC__ < 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ < 3))))))
#ifndef ppNOALLOC
#if (defined (_MSC_VER) || (defined (__GNUC__) && (__GNUC__ < 3)))
namespace std
{
	typedef int bad_alloc;
}
#endif
#endif

// is the wxWindows GUI available?
#if (defined (__WXMSW__) || defined (__WXGTK__) || defined (__WXMAC__) || \
	defined (__WXMOTIF__) || defined (__WXX11__))

	#define ppWXWIN

#endif

// the type of 16-bit and 32-bit integers
#ifdef __LONG_MAX__
	typedef short int16;
	#if (__LONG_MAX__ > 2147483647)
		typedef int int32;
	#else
		typedef long int32;
	#endif
#else
	typedef short int16;
	typedef long int32;
#endif

#endif // _OPTIONS_H_

/// @}
