// @addtogroup rounding
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file doubleRounding.h
///
/// @author Tomasz Kapela
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2006 by the CAPD Group.
//
// This file is part of the CAPD library.  This library is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

#ifndef _DOUBLE_ROUNDING_H_
#define _DOUBLE_ROUNDING_H_

// This allows automatic detection of operating system and compiler
#include "capd/operatingSystemSetting.h"
#include "capd/compilerSetting.h"

namespace capd{
namespace rounding{

///  Rounding modes
enum RoundingMode { RoundUnknown= -1, RoundNearest, RoundDown, RoundUp,  RoundCut };
 
//////////////////////////////////////////////////////////////////////////////
//   DoubleRounding
///
///  Definition of class that switches rounding modes of double numbers
///
///   @author Tomasz Kapela   @date 11-01-2006
//////////////////////////////////////////////////////////////////////////////
class DoubleRounding{

    void initFpUnit();           ///<  Initialize Floating Point Unit

   public:
    DoubleRounding();            ///<  Call initialization of Floating Point Unit

    static void roundNearest();  ///<  Sets rounding to nearest mode
    
    static void roundUp();       ///<  Sets rounding up mode
    
    static void roundDown();     ///<  Sets rounding down mode
    
    static void roundCut();      ///<  Sets rounding towards zero mode

    static RoundingMode test();  ///<  Test that returns actual rounding mode
};

}} // namespace capd::rounding

extern capd::rounding::DoubleRounding initRounding;

#if defined(SUN_OS)
#  include "rounding/sparc.h"
#elif defined(__ppc__) || defined(__powerpc__)
#  include "rounding/powerpc.h"
#elif defined(BORLAND)
#  include "rounding/ibm.h"
#else 
#  include "rounding/linux.h"
#endif

#endif //_DOUBLE_ROUNDING_H_

