/// @addtogroup vectalg
/// @{

/////////////////////////////////////////////////////////////////////////////
/// @file imatrix.hpp
///
/// @author The CAPD Group
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 2000-2005 by the CAPD Group.
//
// This file is part of the CAPD library.  This library is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

#include <stdexcept>

template<typename IMatrixType>
void splitMatrix(IMatrixType& v, IMatrixType& ra)
{
   if(v.numberOfRows()!=ra.numberOfRows() || v.numberOfColumns()!=ra.numberOfColumns())
      throw std::runtime_error("Incompatible sizes of matrices in function split");

   typename IMatrixType::ContainerType::iterator
      b1=v.IMatrixType::ContainerType::begin(),
      e1=v.IMatrixType::ContainerType::end(),
      b2=ra.IMatrixType::ContainerType::begin();
   while(b1!=e1)
   {
      b1->split(*b2);
      ++b1;
      ++b2;
   }
}

template<typename IMatrixType>
IMatrixType midMatrix(const IMatrixType& v)
{
   IMatrixType temp(v.numberOfRows(),v.numberOfColumns(),true);

   typename IMatrixType::ContainerType::iterator
      b1=temp.IMatrixType::ContainerType::begin(),
      e1=temp.IMatrixType::ContainerType::end();

   typename IMatrixType::ContainerType::const_iterator
      i=v.IMatrixType::ContainerType::begin();

   while(b1!=e1)
   {
      *b1 = i->mid();
      ++b1;
      ++i;
   }
   return temp;
}

/// @}
